==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/it.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
    "Storage invalid" : "Archiviazione non valida",
    "Unknown error" : "Errore sconosciuto",
    "Files" : "File",
    "All files" : "Tutti i file",
    "Recent" : "Recenti",
    "File could not be found" : "Il file non può essere trovato",
    "Home" : "Home",
    "Close" : "Chiudi",
    "Favorites" : "Preferiti",
    "Could not create folder \"{dir}\"" : "Impossibile creare la cartella \"{dir}\"",
    "Upload cancelled." : "Caricamento annullato.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile caricare {filename} poiché è una cartella oppure ha una dimensione di 0 byte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spazio insufficiente, stai caricando {size1}, ma è rimasto solo {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La cartella di destinazione \"{dir}\" non esiste più",
    "Not enough free space" : "Spazio libero insufficiente",
    "Uploading..." : "Caricamento in corso...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} di {totalSize} ({bitrate})",
    "Actions" : "Azioni",
    "Download" : "Scarica",
    "Rename" : "Rinomina",
    "Move" : "Sposta",
    "Target folder" : "Cartella di destinazione",
    "Delete" : "Elimina",
    "Disconnect storage" : "Disconnetti archiviazione",
    "Unshare" : "Rimuovi condivisione",
    "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
    "Details" : "Dettagli",
    "Select" : "Seleziona",
    "Pending" : "In corso",
    "Unable to determine date" : "Impossibile determinare la data",
    "This operation is forbidden" : "Questa operazione è vietata",
    "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
    "Could not move \"{file}\", target exists" : "Impossibile spostare \"{file}\", la destinazione esiste già",
    "Could not move \"{file}\"" : "Impossibile spostare \"{file}\"",
    "{newName} already exists" : "{newName} esiste già",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossibile rinominare \"{fileName}\", non esiste più",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{targetName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
    "Could not rename \"{fileName}\"" : "Impossibile rinominare \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossibile creare il file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossibile creare il file \"{file}\" poiché esiste già",
    "Could not create folder \"{dir}\" because it already exists" : "Impossibile creare la cartella \"{dir}\" poiché esiste già",
    "Error deleting file \"{fileName}\"." : "Errore durante l'eliminazione del file \"{fileName}\".",
    "No search results in other folders for '{tag}{filter}{endtag}'" : "Nessun risultato di ricerca in altre cartelle per '{tag}{filter}{endtag}'",
    "Name" : "Nome",
    "Size" : "Dimensione",
    "Modified" : "Modificato",
    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle"],
    "_%n file_::_%n files_" : ["%n file","%n file"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluso %n nascosto","inclusi %n nascosti"],
    "You don’t have permission to upload or create files here" : "Qui non hai i permessi per caricare o creare file",
    "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso"],
    "New" : "Nuovo",
    "\"{name}\" is an invalid file name." : "\"{name}\" non è un nome file valido.",
    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione di {owner} è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione di {owner} è quasi pieno ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["corrispondono a '{filter}'","corrisponde a '{filter}'"],
    "View in folder" : "Visualizza nella cartella",
    "Path" : "Percorso",
    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
    "Favorited" : "Preferiti",
    "Favorite" : "Preferito",
    "Copy local link" : "Copia collegamento locale",
    "Folder" : "Cartella",
    "New folder" : "Nuova cartella",
    "Upload" : "Carica",
    "An error occurred while trying to update the tags" : "Si è verificato un errore durante il tentativo di aggiornare le etichette",
    "Added to favorites" : "Aggiunto ai preferiti",
    "Removed from favorites" : "Rimosso dai preferiti",
    "You added {file} to your favorites" : "Hai aggiunto {file} ai tuoi preferiti",
    "You removed {file} from your favorites" : "Hai rimosso {file} dai tuoi preferiti",
    "File changes" : "Modiche dei file",
    "Created by {user}" : "Creata da {user}",
    "Changed by {user}" : "Modificata da {user}",
    "Deleted by {user}" : "Eliminata da {user}",
    "Restored by {user}" : "Ripristinata da {user}",
    "Renamed by {user}" : "Rinominata da {user}",
    "Moved by {user}" : "Spostata da {user}",
    "You created {file}" : "Hai creato {file}",
    "{user} created {file}" : "{user} ha creato {file}",
    "{file} was created in a public folder" : "{file} è stato creato in una cartella pubblica",
    "You changed {file}" : "Hai modificato {file}",
    "{user} changed {file}" : "{user} ha modificato {file}",
    "You deleted {file}" : "Hai eliminato {file}",
    "{user} deleted {file}" : "{user} ha eliminato {file}",
    "You restored {file}" : "Hai ripristinato {file}",
    "{user} restored {file}" : "{user1} ha ripristinato {file}",
    "You renamed {oldfile} to {newfile}" : "Hai rinominato {oldfile} in {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha rinominato {oldfile} in {newfile}",
    "You moved {oldfile} to {newfile}" : "Hai spostato {oldfile} in {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} ha spostato {oldfile} in {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un file  stato aggiunto o rimosso dai tuoi <strong>preferiti</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un file o una cartella sono stati <strong>modificato</strong> o<strong>rinominati</strong> ",
    "A new file or folder has been <strong>created</strong>" : "Un nuovo file o cartella è stato <strong>creato</strong>",
    "A new file or folder has been <strong>deleted</strong>" : "Un nuovo file o cartella è stato <strong>eliminato</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita le notifiche relative alla creazione e alla modifica dei tuoi <strong>file preferiti</strong> <em>(Solo flusso)</em>",
    "A new file or folder has been <strong>restored</strong>" : "Un nuovo file o una cartella è stato <strong>ripristinato</strong>",
    "Upload (max. %s)" : "Carica (massimo %s)",
    "File handling" : "Gestione file",
    "Maximum upload size" : "Dimensione massima caricamento",
    "max. possible: " : "numero mass.: ",
    "Save" : "Salva",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM potrebbe richiedere 5 minuti perché le modifiche siano applicate.",
    "Missing permissions to edit from here." : "Permessi mancanti per modificare da qui.",
    "Settings" : "Impostazioni",
    "Show hidden files" : "Mostra i file nascosti",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Utilizza questo indirizzo per <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">accedere ai tuoi file con WebDAV</a>",
    "No files in here" : "Qui non c'è alcun file",
    "Upload some content or sync with your devices!" : "Carica alcuni contenuti o sincronizza con i tuoi dispositivi!",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Select all" : "Seleziona tutto",
    "Upload too large" : "Caricamento troppo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "I file che stai provando a caricare superano la dimensione massima consentita su questo server.",
    "No favorites" : "Nessun preferito",
    "Files and folders you mark as favorite will show up here" : "I file e le cartelle che marchi come preferiti saranno mostrati qui",
    "Shared with you" : "Condivisi con te",
    "Shared with others" : "Condivisi con altri",
    "Shared by link" : "Condivisi tramite collegamento",
    "Tags" : "Etichette",
    "Deleted files" : "File eliminati",
    "Text file" : "File di testo",
    "New text file.txt" : "Nuovo file di testo.txt",
    "Storage not available" : "Archiviazione non disponibile",
    "Unable to set upload directory." : "Impossibile impostare una cartella di caricamento.",
    "Invalid Token" : "Token non valido",
    "No file was uploaded. Unknown error" : "Non è stato caricato alcun file. Errore sconosciuto",
    "There is no error, the file uploaded with success" : "Non ci sono errori, il file è stato caricato correttamente",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Il file caricato supera la direttiva upload_max_filesize in php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Il file caricato supera la direttiva MAX_FILE_SIZE specificata nel modulo HTML",
    "The uploaded file was only partially uploaded" : "Il file è stato caricato solo parzialmente",
    "No file was uploaded" : "Non è stato caricato alcun file",
    "Missing a temporary folder" : "Manca una cartella temporanea",
    "Failed to write to disk" : "Scrittura su disco non riuscita",
    "Not enough storage available" : "Spazio di archiviazione insufficiente",
    "The target folder has been moved or deleted." : "La cartella di destinazione è stata spostata o eliminata.",
    "Upload failed. Could not find uploaded file" : "Caricamento non riuscito. Impossibile trovare il file caricato.",
    "Upload failed. Could not get file info." : "Caricamento non riuscito. Impossibile ottenere informazioni sul file.",
    "Invalid directory." : "Cartella non valida.",
    "Total file size {size1} exceeds upload limit {size2}" : "La dimensione totale del file {size1} supera il limite di caricamento {size2}",
    "Error uploading file \"{fileName}\": {message}" : "Errore durante il caricamento del file \"{fileName}\": {message}",
    "Could not get result from server." : "Impossibile ottenere il risultato dal server.",
    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "{hours}:{minutes}:{seconds} ore rimanenti",
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "{minutes}:{seconds} minute{plural_s} left" : "{minutes}:{seconds} minuti rimanenti",
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "{seconds} second{plural_s} left" : "{seconds} secondi rimanenti",
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "Da un momento all'altro...",
    "Soon..." : "Presto...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Caricamento del file in corso. La chiusura della pagina annullerà il caricamento.",
    "No entries in this folder match '{filter}'" : "Nessuna voce in questa cartella corrisponde a '{filter}'",
    "Local link" : "Collegamento locale",
    "{newname} already exists" : "{newname} esiste già",
    "A file or folder has been <strong>changed</strong>" : "Un file o una cartella è stato <strong>modificato</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un file o una cartella è stato <strong>eliminato</strong>",
    "A file or folder has been <strong>restored</strong>" : "Un file o una cartella è stato <strong>ripristinato</strong>",
    "You created %1$s" : "Hai creato %1$s",
    "%2$s created %1$s" : "%2$s ha creato %1$s",
    "%1$s was created in a public folder" : "%1$s è stato creato in una cartella pubblica",
    "You changed %1$s" : "Hai modificato %1$s",
    "%2$s changed %1$s" : "%2$s ha modificato %1$s",
    "You deleted %1$s" : "Hai eliminato %1$s",
    "%2$s deleted %1$s" : "%2$s ha eliminato %1$s",
    "You restored %1$s" : "Hai ripristinato %1$s",
    "%2$s restored %1$s" : "%2$s ha ripristinato %1$s",
    "Changed by %2$s" : "Modificata da %2$s",
    "Deleted by %2$s" : "Eliminata da %2$s",
    "Restored by %2$s" : "Ripristinata da %2$s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/it.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "L'archiviazione è temporaneamente non disponibile",
    "Storage invalid" : "Archiviazione non valida",
    "Unknown error" : "Errore sconosciuto",
    "All files" : "Tutti i file",
    "Recent" : "Recenti",
    "File could not be found" : "Il file non può essere trovato",
    "Home" : "Home",
    "Close" : "Chiudi",
    "Favorites" : "Preferiti",
    "Could not create folder \"{dir}\"" : "Impossibile creare la cartella \"{dir}\"",
    "Upload cancelled." : "Caricamento annullato.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile caricare {filename} poiché è una cartella oppure ha una dimensione di 0 byte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spazio insufficiente, stai caricando {size1}, ma è rimasto solo {size2}",
    "Target folder \"{dir}\" does not exist any more" : "La cartella di destinazione \"{dir}\" non esiste più",
    "Not enough free space" : "Spazio libero insufficiente",
    "Uploading..." : "Caricamento in corso...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} di {totalSize} ({bitrate})",
    "Actions" : "Azioni",
    "Download" : "Scarica",
    "Rename" : "Rinomina",
    "Move" : "Sposta",
    "Target folder" : "Cartella di destinazione",
    "Delete" : "Elimina",
    "Disconnect storage" : "Disconnetti archiviazione",
    "Unshare" : "Rimuovi condivisione",
    "Could not load info for file \"{file}\"" : "Impossibile caricare le informazioni per il file \"{file}\"",
    "Files" : "File",
    "Details" : "Dettagli",
    "Select" : "Seleziona",
    "Pending" : "In corso",
    "Unable to determine date" : "Impossibile determinare la data",
    "This operation is forbidden" : "Questa operazione è vietata",
    "This directory is unavailable, please check the logs or contact the administrator" : "Questa cartella non è disponibile, controlla i log o contatta l'amministratore",
    "Could not move \"{file}\", target exists" : "Impossibile spostare \"{file}\", la destinazione esiste già",
    "Could not move \"{file}\"" : "Impossibile spostare \"{file}\"",
    "{newName} already exists" : "{newName} esiste già",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossibile rinominare \"{fileName}\", non esiste più",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Il nome \"{targetName}\" è attualmente in uso nella cartella \"{dir}\". Scegli un nome diverso.",
    "Could not rename \"{fileName}\"" : "Impossibile rinominare \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossibile creare il file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossibile creare il file \"{file}\" poiché esiste già",
    "Could not create folder \"{dir}\" because it already exists" : "Impossibile creare la cartella \"{dir}\" poiché esiste già",
    "Error deleting file \"{fileName}\"." : "Errore durante l'eliminazione del file \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nessun risultato di ricerca nelle altre cartelle per {tag}{filter}{endtag}",
    "Name" : "Nome",
    "Size" : "Dimensione",
    "Modified" : "Modificato",
    "_%n folder_::_%n folders_" : ["%n cartella","%n cartelle"],
    "_%n file_::_%n files_" : ["%n file","%n file"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluso %n nascosto","inclusi %n nascosti"],
    "You don’t have permission to upload or create files here" : "Qui non hai i permessi per caricare o creare file",
    "_Uploading %n file_::_Uploading %n files_" : ["Caricamento di %n file in corso","Caricamento di %n file in corso"],
    "New" : "Nuovo",
    "\"{name}\" is an invalid file name." : "\"{name}\" non è un nome file valido.",
    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" non è un tipo di file valido",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione di {owner} è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Your storage is full, files can not be updated or synced anymore!" : "Lo spazio di archiviazione è pieno, i file non possono essere più aggiornati o sincronizzati!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione di {owner} è quasi pieno ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lo spazio di archiviazione è quasi pieno ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["corrispondono a '{filter}'","corrisponde a '{filter}'"],
    "View in folder" : "Visualizza nella cartella",
    "Copied!" : "Copiato!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copia link diretto (funziona solo per utenti che hanno accesso a questo file / cartella)",
    "Path" : "Percorso",
    "_%n byte_::_%n bytes_" : ["%n byte","%n byte"],
    "Favorited" : "Preferiti",
    "Favorite" : "Preferito",
    "New folder" : "Nuova cartella",
    "Upload file" : "Carica file",
    "An error occurred while trying to update the tags" : "Si è verificato un errore durante il tentativo di aggiornare le etichette",
    "Added to favorites" : "Aggiunto ai preferiti",
    "Removed from favorites" : "Rimosso dai preferiti",
    "You added {file} to your favorites" : "Hai aggiunto {file} ai tuoi preferiti",
    "You removed {file} from your favorites" : "Hai rimosso {file} dai tuoi preferiti",
    "File changes" : "Modifiche dei file",
    "Created by {user}" : "Creata da {user}",
    "Changed by {user}" : "Modificata da {user}",
    "Deleted by {user}" : "Eliminata da {user}",
    "Restored by {user}" : "Ripristinata da {user}",
    "Renamed by {user}" : "Rinominata da {user}",
    "Moved by {user}" : "Spostata da {user}",
    "\"remote user\"" : "\"utente remoto\"",
    "You created {file}" : "Hai creato {file}",
    "{user} created {file}" : "{user} ha creato {file}",
    "{file} was created in a public folder" : "{file} è stato creato in una cartella pubblica",
    "You changed {file}" : "Hai modificato {file}",
    "{user} changed {file}" : "{user} ha modificato {file}",
    "You deleted {file}" : "Hai eliminato {file}",
    "{user} deleted {file}" : "{user} ha eliminato {file}",
    "You restored {file}" : "Hai ripristinato {file}",
    "{user} restored {file}" : "{user1} ha ripristinato {file}",
    "You renamed {oldfile} to {newfile}" : "Hai rinominato {oldfile} in {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} ha rinominato {oldfile} in {newfile}",
    "You moved {oldfile} to {newfile}" : "Hai spostato {oldfile} in {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} ha spostato {oldfile} in {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un file  stato aggiunto o rimosso dai tuoi <strong>preferiti</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un file o una cartella sono stati <strong>modificato</strong> o<strong>rinominati</strong> ",
    "A new file or folder has been <strong>created</strong>" : "Un nuovo file o cartella è stato <strong>creato</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un file o una cartella è stato <strong>eliminato</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limita le notifiche relative alla creazione e alla modifica dei tuoi <strong>file preferiti</strong> <em>(Solo flusso)</em>",
    "A file or folder has been <strong>restored</strong>" : "Un file o una cartella è stato <strong>ripristinato</strong>",
    "Unlimited" : "Illimitata",
    "Upload (max. %s)" : "Carica (massimo %s)",
    "File handling" : "Gestione file",
    "Maximum upload size" : "Dimensione massima caricamento",
    "max. possible: " : "numero mass.: ",
    "Save" : "Salva",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Con PHP-FPM potrebbe richiedere 5 minuti perché le modifiche siano applicate.",
    "Missing permissions to edit from here." : "Permessi mancanti per modificare da qui.",
    "%s of %s used" : "%s di %s utilizzati",
    "%s used" : "%s utilizzato",
    "Settings" : "Impostazioni",
    "Show hidden files" : "Mostra i file nascosti",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Utilizza questo indirizzo per <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">accedere ai tuoi file con WebDAV</a>",
    "No files in here" : "Qui non c'è alcun file",
    "Upload some content or sync with your devices!" : "Carica alcuni contenuti o sincronizza con i tuoi dispositivi!",
    "No entries found in this folder" : "Nessuna voce trovata in questa cartella",
    "Select all" : "Seleziona tutto",
    "Upload too large" : "Caricamento troppo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "I file che stai provando a caricare superano la dimensione massima consentita su questo server.",
    "No favorites yet" : "Nessun preferito ancora",
    "Files and folders you mark as favorite will show up here" : "I file e le cartelle che marchi come preferiti saranno mostrati qui",
    "Shared with you" : "Condivisi con te",
    "Shared with others" : "Condivisi con altri",
    "Shared by link" : "Condivisi tramite collegamento",
    "Tags" : "Etichette",
    "Deleted files" : "File eliminati",
    "Text file" : "File di testo",
    "New text file.txt" : "Nuovo file di testo.txt",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["{hours}:{minutes}:{seconds} ora rimanente","{hours}:{minutes}:{seconds} ore rimanenti"],
    "{hours}:{minutes}h" : "{hours}:{minutes}h",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["{minutes}:{seconds} minuto rimanente","{minutes}:{seconds} minuti rimanenti"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}m",
    "_{seconds} second left_::_{seconds} seconds left_" : ["{seconds} secondo rimanente","{seconds} secondi rimanenti"],
    "{seconds}s" : "{seconds}s",
    "Any moment now..." : "Da un momento all'altro...",
    "Soon..." : "Presto...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Caricamento del file in corso. La chiusura della pagina annullerà il caricamento.",
    "Copy local link" : "Copia collegamento locale",
    "Folder" : "Cartella",
    "Upload" : "Carica",
    "A new file or folder has been <strong>deleted</strong>" : "Un nuovo file o cartella è stato <strong>eliminato</strong>",
    "A new file or folder has been <strong>restored</strong>" : "Un nuovo file o una cartella è stato <strong>ripristinato</strong>",
    "No favorites" : "Nessun preferito"
},
"nplurals=2; plural=(n != 1);");
